# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .add_image_shape_compatibility_entry_details import AddImageShapeCompatibilityEntryDetails
from .add_network_security_group_security_rules_details import AddNetworkSecurityGroupSecurityRulesDetails
from .add_public_ip_pool_capacity_details import AddPublicIpPoolCapacityDetails
from .add_security_rule_details import AddSecurityRuleDetails
from .added_network_security_group_security_rules import AddedNetworkSecurityGroupSecurityRules
from .app_catalog_listing import AppCatalogListing
from .app_catalog_listing_resource_version import AppCatalogListingResourceVersion
from .app_catalog_listing_resource_version_agreements import AppCatalogListingResourceVersionAgreements
from .app_catalog_listing_resource_version_summary import AppCatalogListingResourceVersionSummary
from .app_catalog_listing_summary import AppCatalogListingSummary
from .app_catalog_subscription import AppCatalogSubscription
from .app_catalog_subscription_summary import AppCatalogSubscriptionSummary
from .attach_boot_volume_details import AttachBootVolumeDetails
from .attach_emulated_volume_details import AttachEmulatedVolumeDetails
from .attach_i_scsi_volume_details import AttachIScsiVolumeDetails
from .attach_load_balancer_details import AttachLoadBalancerDetails
from .attach_paravirtualized_volume_details import AttachParavirtualizedVolumeDetails
from .attach_service_determined_volume_details import AttachServiceDeterminedVolumeDetails
from .attach_vnic_details import AttachVnicDetails
from .attach_volume_details import AttachVolumeDetails
from .bgp_session_info import BgpSessionInfo
from .boolean_image_capability_schema_descriptor import BooleanImageCapabilitySchemaDescriptor
from .boot_volume import BootVolume
from .boot_volume_attachment import BootVolumeAttachment
from .boot_volume_backup import BootVolumeBackup
from .boot_volume_kms_key import BootVolumeKmsKey
from .boot_volume_source_details import BootVolumeSourceDetails
from .boot_volume_source_from_boot_volume_backup_details import BootVolumeSourceFromBootVolumeBackupDetails
from .boot_volume_source_from_boot_volume_details import BootVolumeSourceFromBootVolumeDetails
from .bulk_add_virtual_circuit_public_prefixes_details import BulkAddVirtualCircuitPublicPrefixesDetails
from .bulk_delete_virtual_circuit_public_prefixes_details import BulkDeleteVirtualCircuitPublicPrefixesDetails
from .byoip_allocated_range_collection import ByoipAllocatedRangeCollection
from .byoip_allocated_range_summary import ByoipAllocatedRangeSummary
from .byoip_range import ByoipRange
from .byoip_range_collection import ByoipRangeCollection
from .byoip_range_summary import ByoipRangeSummary
from .capture_console_history_details import CaptureConsoleHistoryDetails
from .change_boot_volume_backup_compartment_details import ChangeBootVolumeBackupCompartmentDetails
from .change_boot_volume_compartment_details import ChangeBootVolumeCompartmentDetails
from .change_byoip_range_compartment_details import ChangeByoipRangeCompartmentDetails
from .change_cluster_network_compartment_details import ChangeClusterNetworkCompartmentDetails
from .change_compute_image_capability_schema_compartment_details import ChangeComputeImageCapabilitySchemaCompartmentDetails
from .change_cpe_compartment_details import ChangeCpeCompartmentDetails
from .change_cross_connect_compartment_details import ChangeCrossConnectCompartmentDetails
from .change_cross_connect_group_compartment_details import ChangeCrossConnectGroupCompartmentDetails
from .change_dedicated_vm_host_compartment_details import ChangeDedicatedVmHostCompartmentDetails
from .change_dhcp_options_compartment_details import ChangeDhcpOptionsCompartmentDetails
from .change_drg_compartment_details import ChangeDrgCompartmentDetails
from .change_ip_sec_connection_compartment_details import ChangeIPSecConnectionCompartmentDetails
from .change_image_compartment_details import ChangeImageCompartmentDetails
from .change_instance_compartment_details import ChangeInstanceCompartmentDetails
from .change_instance_configuration_compartment_details import ChangeInstanceConfigurationCompartmentDetails
from .change_instance_pool_compartment_details import ChangeInstancePoolCompartmentDetails
from .change_internet_gateway_compartment_details import ChangeInternetGatewayCompartmentDetails
from .change_local_peering_gateway_compartment_details import ChangeLocalPeeringGatewayCompartmentDetails
from .change_nat_gateway_compartment_details import ChangeNatGatewayCompartmentDetails
from .change_network_security_group_compartment_details import ChangeNetworkSecurityGroupCompartmentDetails
from .change_public_ip_compartment_details import ChangePublicIpCompartmentDetails
from .change_public_ip_pool_compartment_details import ChangePublicIpPoolCompartmentDetails
from .change_remote_peering_connection_compartment_details import ChangeRemotePeeringConnectionCompartmentDetails
from .change_route_table_compartment_details import ChangeRouteTableCompartmentDetails
from .change_security_list_compartment_details import ChangeSecurityListCompartmentDetails
from .change_service_gateway_compartment_details import ChangeServiceGatewayCompartmentDetails
from .change_subnet_compartment_details import ChangeSubnetCompartmentDetails
from .change_vcn_compartment_details import ChangeVcnCompartmentDetails
from .change_virtual_circuit_compartment_details import ChangeVirtualCircuitCompartmentDetails
from .change_vlan_compartment_details import ChangeVlanCompartmentDetails
from .change_volume_backup_compartment_details import ChangeVolumeBackupCompartmentDetails
from .change_volume_compartment_details import ChangeVolumeCompartmentDetails
from .change_volume_group_backup_compartment_details import ChangeVolumeGroupBackupCompartmentDetails
from .change_volume_group_compartment_details import ChangeVolumeGroupCompartmentDetails
from .cluster_network import ClusterNetwork
from .cluster_network_placement_configuration_details import ClusterNetworkPlacementConfigurationDetails
from .cluster_network_summary import ClusterNetworkSummary
from .compute_global_image_capability_schema import ComputeGlobalImageCapabilitySchema
from .compute_global_image_capability_schema_summary import ComputeGlobalImageCapabilitySchemaSummary
from .compute_global_image_capability_schema_version import ComputeGlobalImageCapabilitySchemaVersion
from .compute_global_image_capability_schema_version_summary import ComputeGlobalImageCapabilitySchemaVersionSummary
from .compute_image_capability_schema import ComputeImageCapabilitySchema
from .compute_image_capability_schema_summary import ComputeImageCapabilitySchemaSummary
from .compute_instance_details import ComputeInstanceDetails
from .connect_local_peering_gateways_details import ConnectLocalPeeringGatewaysDetails
from .connect_remote_peering_connections_details import ConnectRemotePeeringConnectionsDetails
from .console_history import ConsoleHistory
from .copy_boot_volume_backup_details import CopyBootVolumeBackupDetails
from .copy_volume_backup_details import CopyVolumeBackupDetails
from .cpe import Cpe
from .cpe_device_config_answer import CpeDeviceConfigAnswer
from .cpe_device_config_question import CpeDeviceConfigQuestion
from .cpe_device_info import CpeDeviceInfo
from .cpe_device_shape_detail import CpeDeviceShapeDetail
from .cpe_device_shape_summary import CpeDeviceShapeSummary
from .create_app_catalog_subscription_details import CreateAppCatalogSubscriptionDetails
from .create_boot_volume_backup_details import CreateBootVolumeBackupDetails
from .create_boot_volume_details import CreateBootVolumeDetails
from .create_byoip_range_details import CreateByoipRangeDetails
from .create_cluster_network_details import CreateClusterNetworkDetails
from .create_cluster_network_instance_pool_details import CreateClusterNetworkInstancePoolDetails
from .create_compute_image_capability_schema_details import CreateComputeImageCapabilitySchemaDetails
from .create_cpe_details import CreateCpeDetails
from .create_cross_connect_details import CreateCrossConnectDetails
from .create_cross_connect_group_details import CreateCrossConnectGroupDetails
from .create_dedicated_vm_host_details import CreateDedicatedVmHostDetails
from .create_dhcp_details import CreateDhcpDetails
from .create_drg_attachment_details import CreateDrgAttachmentDetails
from .create_drg_details import CreateDrgDetails
from .create_ip_sec_connection_details import CreateIPSecConnectionDetails
from .create_ip_sec_connection_tunnel_details import CreateIPSecConnectionTunnelDetails
from .create_ip_sec_tunnel_bgp_session_details import CreateIPSecTunnelBgpSessionDetails
from .create_image_details import CreateImageDetails
from .create_instance_configuration_base import CreateInstanceConfigurationBase
from .create_instance_configuration_details import CreateInstanceConfigurationDetails
from .create_instance_configuration_from_instance_details import CreateInstanceConfigurationFromInstanceDetails
from .create_instance_console_connection_details import CreateInstanceConsoleConnectionDetails
from .create_instance_pool_details import CreateInstancePoolDetails
from .create_instance_pool_placement_configuration_details import CreateInstancePoolPlacementConfigurationDetails
from .create_internet_gateway_details import CreateInternetGatewayDetails
from .create_ipv6_details import CreateIpv6Details
from .create_local_peering_gateway_details import CreateLocalPeeringGatewayDetails
from .create_nat_gateway_details import CreateNatGatewayDetails
from .create_network_security_group_details import CreateNetworkSecurityGroupDetails
from .create_private_ip_details import CreatePrivateIpDetails
from .create_public_ip_details import CreatePublicIpDetails
from .create_public_ip_pool_details import CreatePublicIpPoolDetails
from .create_remote_peering_connection_details import CreateRemotePeeringConnectionDetails
from .create_route_table_details import CreateRouteTableDetails
from .create_security_list_details import CreateSecurityListDetails
from .create_service_gateway_details import CreateServiceGatewayDetails
from .create_subnet_details import CreateSubnetDetails
from .create_vcn_details import CreateVcnDetails
from .create_virtual_circuit_details import CreateVirtualCircuitDetails
from .create_virtual_circuit_public_prefix_details import CreateVirtualCircuitPublicPrefixDetails
from .create_vlan_details import CreateVlanDetails
from .create_vnic_details import CreateVnicDetails
from .create_volume_backup_details import CreateVolumeBackupDetails
from .create_volume_backup_policy_assignment_details import CreateVolumeBackupPolicyAssignmentDetails
from .create_volume_backup_policy_details import CreateVolumeBackupPolicyDetails
from .create_volume_details import CreateVolumeDetails
from .create_volume_group_backup_details import CreateVolumeGroupBackupDetails
from .create_volume_group_details import CreateVolumeGroupDetails
from .cross_connect import CrossConnect
from .cross_connect_group import CrossConnectGroup
from .cross_connect_location import CrossConnectLocation
from .cross_connect_mapping import CrossConnectMapping
from .cross_connect_port_speed_shape import CrossConnectPortSpeedShape
from .cross_connect_status import CrossConnectStatus
from .dedicated_vm_host import DedicatedVmHost
from .dedicated_vm_host_instance_shape_summary import DedicatedVmHostInstanceShapeSummary
from .dedicated_vm_host_instance_summary import DedicatedVmHostInstanceSummary
from .dedicated_vm_host_shape_summary import DedicatedVmHostShapeSummary
from .dedicated_vm_host_summary import DedicatedVmHostSummary
from .delete_virtual_circuit_public_prefix_details import DeleteVirtualCircuitPublicPrefixDetails
from .detach_load_balancer_details import DetachLoadBalancerDetails
from .device import Device
from .dhcp_dns_option import DhcpDnsOption
from .dhcp_option import DhcpOption
from .dhcp_options import DhcpOptions
from .dhcp_search_domain_option import DhcpSearchDomainOption
from .drg import Drg
from .drg_attachment import DrgAttachment
from .drg_redundancy_status import DrgRedundancyStatus
from .egress_security_rule import EgressSecurityRule
from .emulated_volume_attachment import EmulatedVolumeAttachment
from .enum_integer_image_capability_descriptor import EnumIntegerImageCapabilityDescriptor
from .enum_string_image_capability_schema_descriptor import EnumStringImageCapabilitySchemaDescriptor
from .export_image_details import ExportImageDetails
from .export_image_via_object_storage_tuple_details import ExportImageViaObjectStorageTupleDetails
from .export_image_via_object_storage_uri_details import ExportImageViaObjectStorageUriDetails
from .fast_connect_provider_service import FastConnectProviderService
from .fast_connect_provider_service_key import FastConnectProviderServiceKey
from .get_public_ip_by_ip_address_details import GetPublicIpByIpAddressDetails
from .get_public_ip_by_private_ip_id_details import GetPublicIpByPrivateIpIdDetails
from .ip_sec_connection import IPSecConnection
from .ip_sec_connection_device_config import IPSecConnectionDeviceConfig
from .ip_sec_connection_device_status import IPSecConnectionDeviceStatus
from .ip_sec_connection_tunnel import IPSecConnectionTunnel
from .ip_sec_connection_tunnel_shared_secret import IPSecConnectionTunnelSharedSecret
from .i_scsi_volume_attachment import IScsiVolumeAttachment
from .icmp_options import IcmpOptions
from .image import Image
from .image_capability_schema_descriptor import ImageCapabilitySchemaDescriptor
from .image_memory_constraints import ImageMemoryConstraints
from .image_ocpu_constraints import ImageOcpuConstraints
from .image_shape_compatibility_entry import ImageShapeCompatibilityEntry
from .image_shape_compatibility_summary import ImageShapeCompatibilitySummary
from .image_source_details import ImageSourceDetails
from .image_source_via_object_storage_tuple_details import ImageSourceViaObjectStorageTupleDetails
from .image_source_via_object_storage_uri_details import ImageSourceViaObjectStorageUriDetails
from .ingress_security_rule import IngressSecurityRule
from .instance import Instance
from .instance_agent_config import InstanceAgentConfig
from .instance_agent_features import InstanceAgentFeatures
from .instance_availability_config import InstanceAvailabilityConfig
from .instance_configuration import InstanceConfiguration
from .instance_configuration_attach_vnic_details import InstanceConfigurationAttachVnicDetails
from .instance_configuration_attach_volume_details import InstanceConfigurationAttachVolumeDetails
from .instance_configuration_availability_config import InstanceConfigurationAvailabilityConfig
from .instance_configuration_block_volume_details import InstanceConfigurationBlockVolumeDetails
from .instance_configuration_create_vnic_details import InstanceConfigurationCreateVnicDetails
from .instance_configuration_create_volume_details import InstanceConfigurationCreateVolumeDetails
from .instance_configuration_instance_details import InstanceConfigurationInstanceDetails
from .instance_configuration_instance_source_details import InstanceConfigurationInstanceSourceDetails
from .instance_configuration_instance_source_via_boot_volume_details import InstanceConfigurationInstanceSourceViaBootVolumeDetails
from .instance_configuration_instance_source_via_image_details import InstanceConfigurationInstanceSourceViaImageDetails
from .instance_configuration_iscsi_attach_volume_details import InstanceConfigurationIscsiAttachVolumeDetails
from .instance_configuration_launch_instance_agent_config_details import InstanceConfigurationLaunchInstanceAgentConfigDetails
from .instance_configuration_launch_instance_details import InstanceConfigurationLaunchInstanceDetails
from .instance_configuration_launch_instance_shape_config_details import InstanceConfigurationLaunchInstanceShapeConfigDetails
from .instance_configuration_launch_options import InstanceConfigurationLaunchOptions
from .instance_configuration_paravirtualized_attach_volume_details import InstanceConfigurationParavirtualizedAttachVolumeDetails
from .instance_configuration_summary import InstanceConfigurationSummary
from .instance_configuration_volume_source_details import InstanceConfigurationVolumeSourceDetails
from .instance_configuration_volume_source_from_volume_backup_details import InstanceConfigurationVolumeSourceFromVolumeBackupDetails
from .instance_configuration_volume_source_from_volume_details import InstanceConfigurationVolumeSourceFromVolumeDetails
from .instance_console_connection import InstanceConsoleConnection
from .instance_credentials import InstanceCredentials
from .instance_pool import InstancePool
from .instance_pool_instance_load_balancer_backend import InstancePoolInstanceLoadBalancerBackend
from .instance_pool_load_balancer_attachment import InstancePoolLoadBalancerAttachment
from .instance_pool_placement_configuration import InstancePoolPlacementConfiguration
from .instance_pool_placement_secondary_vnic_subnet import InstancePoolPlacementSecondaryVnicSubnet
from .instance_pool_summary import InstancePoolSummary
from .instance_shape_config import InstanceShapeConfig
from .instance_source_details import InstanceSourceDetails
from .instance_source_via_boot_volume_details import InstanceSourceViaBootVolumeDetails
from .instance_source_via_image_details import InstanceSourceViaImageDetails
from .instance_summary import InstanceSummary
from .internet_gateway import InternetGateway
from .ipv6 import Ipv6
from .launch_instance_agent_config_details import LaunchInstanceAgentConfigDetails
from .launch_instance_availability_config_details import LaunchInstanceAvailabilityConfigDetails
from .launch_instance_details import LaunchInstanceDetails
from .launch_instance_shape_config_details import LaunchInstanceShapeConfigDetails
from .launch_options import LaunchOptions
from .letter_of_authority import LetterOfAuthority
from .local_peering_gateway import LocalPeeringGateway
from .nat_gateway import NatGateway
from .network_security_group import NetworkSecurityGroup
from .network_security_group_vnic import NetworkSecurityGroupVnic
from .paravirtualized_volume_attachment import ParavirtualizedVolumeAttachment
from .peer_region_for_remote_peering import PeerRegionForRemotePeering
from .port_range import PortRange
from .private_ip import PrivateIp
from .public_ip import PublicIp
from .public_ip_pool import PublicIpPool
from .public_ip_pool_collection import PublicIpPoolCollection
from .public_ip_pool_summary import PublicIpPoolSummary
from .remote_peering_connection import RemotePeeringConnection
from .remove_network_security_group_security_rules_details import RemoveNetworkSecurityGroupSecurityRulesDetails
from .remove_public_ip_pool_capacity_details import RemovePublicIpPoolCapacityDetails
from .route_rule import RouteRule
from .route_table import RouteTable
from .security_list import SecurityList
from .security_rule import SecurityRule
from .service import Service
from .service_gateway import ServiceGateway
from .service_id_request_details import ServiceIdRequestDetails
from .service_id_response_details import ServiceIdResponseDetails
from .shape import Shape
from .shape_max_vnic_attachment_options import ShapeMaxVnicAttachmentOptions
from .shape_memory_options import ShapeMemoryOptions
from .shape_networking_bandwidth_options import ShapeNetworkingBandwidthOptions
from .shape_ocpu_options import ShapeOcpuOptions
from .subnet import Subnet
from .tcp_options import TcpOptions
from .tunnel_config import TunnelConfig
from .tunnel_cpe_device_config import TunnelCpeDeviceConfig
from .tunnel_status import TunnelStatus
from .udp_options import UdpOptions
from .update_boot_volume_backup_details import UpdateBootVolumeBackupDetails
from .update_boot_volume_details import UpdateBootVolumeDetails
from .update_boot_volume_kms_key_details import UpdateBootVolumeKmsKeyDetails
from .update_byoip_range_details import UpdateByoipRangeDetails
from .update_cluster_network_details import UpdateClusterNetworkDetails
from .update_compute_image_capability_schema_details import UpdateComputeImageCapabilitySchemaDetails
from .update_console_history_details import UpdateConsoleHistoryDetails
from .update_cpe_details import UpdateCpeDetails
from .update_cross_connect_details import UpdateCrossConnectDetails
from .update_cross_connect_group_details import UpdateCrossConnectGroupDetails
from .update_dedicated_vm_host_details import UpdateDedicatedVmHostDetails
from .update_dhcp_details import UpdateDhcpDetails
from .update_drg_attachment_details import UpdateDrgAttachmentDetails
from .update_drg_details import UpdateDrgDetails
from .update_ip_sec_connection_details import UpdateIPSecConnectionDetails
from .update_ip_sec_connection_tunnel_details import UpdateIPSecConnectionTunnelDetails
from .update_ip_sec_connection_tunnel_shared_secret_details import UpdateIPSecConnectionTunnelSharedSecretDetails
from .update_ip_sec_tunnel_bgp_session_details import UpdateIPSecTunnelBgpSessionDetails
from .update_image_details import UpdateImageDetails
from .update_instance_agent_config_details import UpdateInstanceAgentConfigDetails
from .update_instance_availability_config_details import UpdateInstanceAvailabilityConfigDetails
from .update_instance_configuration_details import UpdateInstanceConfigurationDetails
from .update_instance_console_connection_details import UpdateInstanceConsoleConnectionDetails
from .update_instance_details import UpdateInstanceDetails
from .update_instance_pool_details import UpdateInstancePoolDetails
from .update_instance_pool_placement_configuration_details import UpdateInstancePoolPlacementConfigurationDetails
from .update_instance_shape_config_details import UpdateInstanceShapeConfigDetails
from .update_internet_gateway_details import UpdateInternetGatewayDetails
from .update_ipv6_details import UpdateIpv6Details
from .update_launch_options import UpdateLaunchOptions
from .update_local_peering_gateway_details import UpdateLocalPeeringGatewayDetails
from .update_nat_gateway_details import UpdateNatGatewayDetails
from .update_network_security_group_details import UpdateNetworkSecurityGroupDetails
from .update_network_security_group_security_rules_details import UpdateNetworkSecurityGroupSecurityRulesDetails
from .update_private_ip_details import UpdatePrivateIpDetails
from .update_public_ip_details import UpdatePublicIpDetails
from .update_public_ip_pool_details import UpdatePublicIpPoolDetails
from .update_remote_peering_connection_details import UpdateRemotePeeringConnectionDetails
from .update_route_table_details import UpdateRouteTableDetails
from .update_security_list_details import UpdateSecurityListDetails
from .update_security_rule_details import UpdateSecurityRuleDetails
from .update_service_gateway_details import UpdateServiceGatewayDetails
from .update_subnet_details import UpdateSubnetDetails
from .update_tunnel_cpe_device_config_details import UpdateTunnelCpeDeviceConfigDetails
from .update_vcn_details import UpdateVcnDetails
from .update_virtual_circuit_details import UpdateVirtualCircuitDetails
from .update_vlan_details import UpdateVlanDetails
from .update_vnic_details import UpdateVnicDetails
from .update_volume_backup_details import UpdateVolumeBackupDetails
from .update_volume_backup_policy_details import UpdateVolumeBackupPolicyDetails
from .update_volume_details import UpdateVolumeDetails
from .update_volume_group_backup_details import UpdateVolumeGroupBackupDetails
from .update_volume_group_details import UpdateVolumeGroupDetails
from .update_volume_kms_key_details import UpdateVolumeKmsKeyDetails
from .updated_network_security_group_security_rules import UpdatedNetworkSecurityGroupSecurityRules
from .vcn import Vcn
from .virtual_circuit import VirtualCircuit
from .virtual_circuit_bandwidth_shape import VirtualCircuitBandwidthShape
from .virtual_circuit_public_prefix import VirtualCircuitPublicPrefix
from .vlan import Vlan
from .vnic import Vnic
from .vnic_attachment import VnicAttachment
from .volume import Volume
from .volume_attachment import VolumeAttachment
from .volume_backup import VolumeBackup
from .volume_backup_policy import VolumeBackupPolicy
from .volume_backup_policy_assignment import VolumeBackupPolicyAssignment
from .volume_backup_schedule import VolumeBackupSchedule
from .volume_group import VolumeGroup
from .volume_group_backup import VolumeGroupBackup
from .volume_group_source_details import VolumeGroupSourceDetails
from .volume_group_source_from_volume_group_backup_details import VolumeGroupSourceFromVolumeGroupBackupDetails
from .volume_group_source_from_volume_group_details import VolumeGroupSourceFromVolumeGroupDetails
from .volume_group_source_from_volumes_details import VolumeGroupSourceFromVolumesDetails
from .volume_kms_key import VolumeKmsKey
from .volume_source_details import VolumeSourceDetails
from .volume_source_from_volume_backup_details import VolumeSourceFromVolumeBackupDetails
from .volume_source_from_volume_details import VolumeSourceFromVolumeDetails

# Maps type names to classes for core services.
core_type_mapping = {
    "AddImageShapeCompatibilityEntryDetails": AddImageShapeCompatibilityEntryDetails,
    "AddNetworkSecurityGroupSecurityRulesDetails": AddNetworkSecurityGroupSecurityRulesDetails,
    "AddPublicIpPoolCapacityDetails": AddPublicIpPoolCapacityDetails,
    "AddSecurityRuleDetails": AddSecurityRuleDetails,
    "AddedNetworkSecurityGroupSecurityRules": AddedNetworkSecurityGroupSecurityRules,
    "AppCatalogListing": AppCatalogListing,
    "AppCatalogListingResourceVersion": AppCatalogListingResourceVersion,
    "AppCatalogListingResourceVersionAgreements": AppCatalogListingResourceVersionAgreements,
    "AppCatalogListingResourceVersionSummary": AppCatalogListingResourceVersionSummary,
    "AppCatalogListingSummary": AppCatalogListingSummary,
    "AppCatalogSubscription": AppCatalogSubscription,
    "AppCatalogSubscriptionSummary": AppCatalogSubscriptionSummary,
    "AttachBootVolumeDetails": AttachBootVolumeDetails,
    "AttachEmulatedVolumeDetails": AttachEmulatedVolumeDetails,
    "AttachIScsiVolumeDetails": AttachIScsiVolumeDetails,
    "AttachLoadBalancerDetails": AttachLoadBalancerDetails,
    "AttachParavirtualizedVolumeDetails": AttachParavirtualizedVolumeDetails,
    "AttachServiceDeterminedVolumeDetails": AttachServiceDeterminedVolumeDetails,
    "AttachVnicDetails": AttachVnicDetails,
    "AttachVolumeDetails": AttachVolumeDetails,
    "BgpSessionInfo": BgpSessionInfo,
    "BooleanImageCapabilitySchemaDescriptor": BooleanImageCapabilitySchemaDescriptor,
    "BootVolume": BootVolume,
    "BootVolumeAttachment": BootVolumeAttachment,
    "BootVolumeBackup": BootVolumeBackup,
    "BootVolumeKmsKey": BootVolumeKmsKey,
    "BootVolumeSourceDetails": BootVolumeSourceDetails,
    "BootVolumeSourceFromBootVolumeBackupDetails": BootVolumeSourceFromBootVolumeBackupDetails,
    "BootVolumeSourceFromBootVolumeDetails": BootVolumeSourceFromBootVolumeDetails,
    "BulkAddVirtualCircuitPublicPrefixesDetails": BulkAddVirtualCircuitPublicPrefixesDetails,
    "BulkDeleteVirtualCircuitPublicPrefixesDetails": BulkDeleteVirtualCircuitPublicPrefixesDetails,
    "ByoipAllocatedRangeCollection": ByoipAllocatedRangeCollection,
    "ByoipAllocatedRangeSummary": ByoipAllocatedRangeSummary,
    "ByoipRange": ByoipRange,
    "ByoipRangeCollection": ByoipRangeCollection,
    "ByoipRangeSummary": ByoipRangeSummary,
    "CaptureConsoleHistoryDetails": CaptureConsoleHistoryDetails,
    "ChangeBootVolumeBackupCompartmentDetails": ChangeBootVolumeBackupCompartmentDetails,
    "ChangeBootVolumeCompartmentDetails": ChangeBootVolumeCompartmentDetails,
    "ChangeByoipRangeCompartmentDetails": ChangeByoipRangeCompartmentDetails,
    "ChangeClusterNetworkCompartmentDetails": ChangeClusterNetworkCompartmentDetails,
    "ChangeComputeImageCapabilitySchemaCompartmentDetails": ChangeComputeImageCapabilitySchemaCompartmentDetails,
    "ChangeCpeCompartmentDetails": ChangeCpeCompartmentDetails,
    "ChangeCrossConnectCompartmentDetails": ChangeCrossConnectCompartmentDetails,
    "ChangeCrossConnectGroupCompartmentDetails": ChangeCrossConnectGroupCompartmentDetails,
    "ChangeDedicatedVmHostCompartmentDetails": ChangeDedicatedVmHostCompartmentDetails,
    "ChangeDhcpOptionsCompartmentDetails": ChangeDhcpOptionsCompartmentDetails,
    "ChangeDrgCompartmentDetails": ChangeDrgCompartmentDetails,
    "ChangeIPSecConnectionCompartmentDetails": ChangeIPSecConnectionCompartmentDetails,
    "ChangeImageCompartmentDetails": ChangeImageCompartmentDetails,
    "ChangeInstanceCompartmentDetails": ChangeInstanceCompartmentDetails,
    "ChangeInstanceConfigurationCompartmentDetails": ChangeInstanceConfigurationCompartmentDetails,
    "ChangeInstancePoolCompartmentDetails": ChangeInstancePoolCompartmentDetails,
    "ChangeInternetGatewayCompartmentDetails": ChangeInternetGatewayCompartmentDetails,
    "ChangeLocalPeeringGatewayCompartmentDetails": ChangeLocalPeeringGatewayCompartmentDetails,
    "ChangeNatGatewayCompartmentDetails": ChangeNatGatewayCompartmentDetails,
    "ChangeNetworkSecurityGroupCompartmentDetails": ChangeNetworkSecurityGroupCompartmentDetails,
    "ChangePublicIpCompartmentDetails": ChangePublicIpCompartmentDetails,
    "ChangePublicIpPoolCompartmentDetails": ChangePublicIpPoolCompartmentDetails,
    "ChangeRemotePeeringConnectionCompartmentDetails": ChangeRemotePeeringConnectionCompartmentDetails,
    "ChangeRouteTableCompartmentDetails": ChangeRouteTableCompartmentDetails,
    "ChangeSecurityListCompartmentDetails": ChangeSecurityListCompartmentDetails,
    "ChangeServiceGatewayCompartmentDetails": ChangeServiceGatewayCompartmentDetails,
    "ChangeSubnetCompartmentDetails": ChangeSubnetCompartmentDetails,
    "ChangeVcnCompartmentDetails": ChangeVcnCompartmentDetails,
    "ChangeVirtualCircuitCompartmentDetails": ChangeVirtualCircuitCompartmentDetails,
    "ChangeVlanCompartmentDetails": ChangeVlanCompartmentDetails,
    "ChangeVolumeBackupCompartmentDetails": ChangeVolumeBackupCompartmentDetails,
    "ChangeVolumeCompartmentDetails": ChangeVolumeCompartmentDetails,
    "ChangeVolumeGroupBackupCompartmentDetails": ChangeVolumeGroupBackupCompartmentDetails,
    "ChangeVolumeGroupCompartmentDetails": ChangeVolumeGroupCompartmentDetails,
    "ClusterNetwork": ClusterNetwork,
    "ClusterNetworkPlacementConfigurationDetails": ClusterNetworkPlacementConfigurationDetails,
    "ClusterNetworkSummary": ClusterNetworkSummary,
    "ComputeGlobalImageCapabilitySchema": ComputeGlobalImageCapabilitySchema,
    "ComputeGlobalImageCapabilitySchemaSummary": ComputeGlobalImageCapabilitySchemaSummary,
    "ComputeGlobalImageCapabilitySchemaVersion": ComputeGlobalImageCapabilitySchemaVersion,
    "ComputeGlobalImageCapabilitySchemaVersionSummary": ComputeGlobalImageCapabilitySchemaVersionSummary,
    "ComputeImageCapabilitySchema": ComputeImageCapabilitySchema,
    "ComputeImageCapabilitySchemaSummary": ComputeImageCapabilitySchemaSummary,
    "ComputeInstanceDetails": ComputeInstanceDetails,
    "ConnectLocalPeeringGatewaysDetails": ConnectLocalPeeringGatewaysDetails,
    "ConnectRemotePeeringConnectionsDetails": ConnectRemotePeeringConnectionsDetails,
    "ConsoleHistory": ConsoleHistory,
    "CopyBootVolumeBackupDetails": CopyBootVolumeBackupDetails,
    "CopyVolumeBackupDetails": CopyVolumeBackupDetails,
    "Cpe": Cpe,
    "CpeDeviceConfigAnswer": CpeDeviceConfigAnswer,
    "CpeDeviceConfigQuestion": CpeDeviceConfigQuestion,
    "CpeDeviceInfo": CpeDeviceInfo,
    "CpeDeviceShapeDetail": CpeDeviceShapeDetail,
    "CpeDeviceShapeSummary": CpeDeviceShapeSummary,
    "CreateAppCatalogSubscriptionDetails": CreateAppCatalogSubscriptionDetails,
    "CreateBootVolumeBackupDetails": CreateBootVolumeBackupDetails,
    "CreateBootVolumeDetails": CreateBootVolumeDetails,
    "CreateByoipRangeDetails": CreateByoipRangeDetails,
    "CreateClusterNetworkDetails": CreateClusterNetworkDetails,
    "CreateClusterNetworkInstancePoolDetails": CreateClusterNetworkInstancePoolDetails,
    "CreateComputeImageCapabilitySchemaDetails": CreateComputeImageCapabilitySchemaDetails,
    "CreateCpeDetails": CreateCpeDetails,
    "CreateCrossConnectDetails": CreateCrossConnectDetails,
    "CreateCrossConnectGroupDetails": CreateCrossConnectGroupDetails,
    "CreateDedicatedVmHostDetails": CreateDedicatedVmHostDetails,
    "CreateDhcpDetails": CreateDhcpDetails,
    "CreateDrgAttachmentDetails": CreateDrgAttachmentDetails,
    "CreateDrgDetails": CreateDrgDetails,
    "CreateIPSecConnectionDetails": CreateIPSecConnectionDetails,
    "CreateIPSecConnectionTunnelDetails": CreateIPSecConnectionTunnelDetails,
    "CreateIPSecTunnelBgpSessionDetails": CreateIPSecTunnelBgpSessionDetails,
    "CreateImageDetails": CreateImageDetails,
    "CreateInstanceConfigurationBase": CreateInstanceConfigurationBase,
    "CreateInstanceConfigurationDetails": CreateInstanceConfigurationDetails,
    "CreateInstanceConfigurationFromInstanceDetails": CreateInstanceConfigurationFromInstanceDetails,
    "CreateInstanceConsoleConnectionDetails": CreateInstanceConsoleConnectionDetails,
    "CreateInstancePoolDetails": CreateInstancePoolDetails,
    "CreateInstancePoolPlacementConfigurationDetails": CreateInstancePoolPlacementConfigurationDetails,
    "CreateInternetGatewayDetails": CreateInternetGatewayDetails,
    "CreateIpv6Details": CreateIpv6Details,
    "CreateLocalPeeringGatewayDetails": CreateLocalPeeringGatewayDetails,
    "CreateNatGatewayDetails": CreateNatGatewayDetails,
    "CreateNetworkSecurityGroupDetails": CreateNetworkSecurityGroupDetails,
    "CreatePrivateIpDetails": CreatePrivateIpDetails,
    "CreatePublicIpDetails": CreatePublicIpDetails,
    "CreatePublicIpPoolDetails": CreatePublicIpPoolDetails,
    "CreateRemotePeeringConnectionDetails": CreateRemotePeeringConnectionDetails,
    "CreateRouteTableDetails": CreateRouteTableDetails,
    "CreateSecurityListDetails": CreateSecurityListDetails,
    "CreateServiceGatewayDetails": CreateServiceGatewayDetails,
    "CreateSubnetDetails": CreateSubnetDetails,
    "CreateVcnDetails": CreateVcnDetails,
    "CreateVirtualCircuitDetails": CreateVirtualCircuitDetails,
    "CreateVirtualCircuitPublicPrefixDetails": CreateVirtualCircuitPublicPrefixDetails,
    "CreateVlanDetails": CreateVlanDetails,
    "CreateVnicDetails": CreateVnicDetails,
    "CreateVolumeBackupDetails": CreateVolumeBackupDetails,
    "CreateVolumeBackupPolicyAssignmentDetails": CreateVolumeBackupPolicyAssignmentDetails,
    "CreateVolumeBackupPolicyDetails": CreateVolumeBackupPolicyDetails,
    "CreateVolumeDetails": CreateVolumeDetails,
    "CreateVolumeGroupBackupDetails": CreateVolumeGroupBackupDetails,
    "CreateVolumeGroupDetails": CreateVolumeGroupDetails,
    "CrossConnect": CrossConnect,
    "CrossConnectGroup": CrossConnectGroup,
    "CrossConnectLocation": CrossConnectLocation,
    "CrossConnectMapping": CrossConnectMapping,
    "CrossConnectPortSpeedShape": CrossConnectPortSpeedShape,
    "CrossConnectStatus": CrossConnectStatus,
    "DedicatedVmHost": DedicatedVmHost,
    "DedicatedVmHostInstanceShapeSummary": DedicatedVmHostInstanceShapeSummary,
    "DedicatedVmHostInstanceSummary": DedicatedVmHostInstanceSummary,
    "DedicatedVmHostShapeSummary": DedicatedVmHostShapeSummary,
    "DedicatedVmHostSummary": DedicatedVmHostSummary,
    "DeleteVirtualCircuitPublicPrefixDetails": DeleteVirtualCircuitPublicPrefixDetails,
    "DetachLoadBalancerDetails": DetachLoadBalancerDetails,
    "Device": Device,
    "DhcpDnsOption": DhcpDnsOption,
    "DhcpOption": DhcpOption,
    "DhcpOptions": DhcpOptions,
    "DhcpSearchDomainOption": DhcpSearchDomainOption,
    "Drg": Drg,
    "DrgAttachment": DrgAttachment,
    "DrgRedundancyStatus": DrgRedundancyStatus,
    "EgressSecurityRule": EgressSecurityRule,
    "EmulatedVolumeAttachment": EmulatedVolumeAttachment,
    "EnumIntegerImageCapabilityDescriptor": EnumIntegerImageCapabilityDescriptor,
    "EnumStringImageCapabilitySchemaDescriptor": EnumStringImageCapabilitySchemaDescriptor,
    "ExportImageDetails": ExportImageDetails,
    "ExportImageViaObjectStorageTupleDetails": ExportImageViaObjectStorageTupleDetails,
    "ExportImageViaObjectStorageUriDetails": ExportImageViaObjectStorageUriDetails,
    "FastConnectProviderService": FastConnectProviderService,
    "FastConnectProviderServiceKey": FastConnectProviderServiceKey,
    "GetPublicIpByIpAddressDetails": GetPublicIpByIpAddressDetails,
    "GetPublicIpByPrivateIpIdDetails": GetPublicIpByPrivateIpIdDetails,
    "IPSecConnection": IPSecConnection,
    "IPSecConnectionDeviceConfig": IPSecConnectionDeviceConfig,
    "IPSecConnectionDeviceStatus": IPSecConnectionDeviceStatus,
    "IPSecConnectionTunnel": IPSecConnectionTunnel,
    "IPSecConnectionTunnelSharedSecret": IPSecConnectionTunnelSharedSecret,
    "IScsiVolumeAttachment": IScsiVolumeAttachment,
    "IcmpOptions": IcmpOptions,
    "Image": Image,
    "ImageCapabilitySchemaDescriptor": ImageCapabilitySchemaDescriptor,
    "ImageMemoryConstraints": ImageMemoryConstraints,
    "ImageOcpuConstraints": ImageOcpuConstraints,
    "ImageShapeCompatibilityEntry": ImageShapeCompatibilityEntry,
    "ImageShapeCompatibilitySummary": ImageShapeCompatibilitySummary,
    "ImageSourceDetails": ImageSourceDetails,
    "ImageSourceViaObjectStorageTupleDetails": ImageSourceViaObjectStorageTupleDetails,
    "ImageSourceViaObjectStorageUriDetails": ImageSourceViaObjectStorageUriDetails,
    "IngressSecurityRule": IngressSecurityRule,
    "Instance": Instance,
    "InstanceAgentConfig": InstanceAgentConfig,
    "InstanceAgentFeatures": InstanceAgentFeatures,
    "InstanceAvailabilityConfig": InstanceAvailabilityConfig,
    "InstanceConfiguration": InstanceConfiguration,
    "InstanceConfigurationAttachVnicDetails": InstanceConfigurationAttachVnicDetails,
    "InstanceConfigurationAttachVolumeDetails": InstanceConfigurationAttachVolumeDetails,
    "InstanceConfigurationAvailabilityConfig": InstanceConfigurationAvailabilityConfig,
    "InstanceConfigurationBlockVolumeDetails": InstanceConfigurationBlockVolumeDetails,
    "InstanceConfigurationCreateVnicDetails": InstanceConfigurationCreateVnicDetails,
    "InstanceConfigurationCreateVolumeDetails": InstanceConfigurationCreateVolumeDetails,
    "InstanceConfigurationInstanceDetails": InstanceConfigurationInstanceDetails,
    "InstanceConfigurationInstanceSourceDetails": InstanceConfigurationInstanceSourceDetails,
    "InstanceConfigurationInstanceSourceViaBootVolumeDetails": InstanceConfigurationInstanceSourceViaBootVolumeDetails,
    "InstanceConfigurationInstanceSourceViaImageDetails": InstanceConfigurationInstanceSourceViaImageDetails,
    "InstanceConfigurationIscsiAttachVolumeDetails": InstanceConfigurationIscsiAttachVolumeDetails,
    "InstanceConfigurationLaunchInstanceAgentConfigDetails": InstanceConfigurationLaunchInstanceAgentConfigDetails,
    "InstanceConfigurationLaunchInstanceDetails": InstanceConfigurationLaunchInstanceDetails,
    "InstanceConfigurationLaunchInstanceShapeConfigDetails": InstanceConfigurationLaunchInstanceShapeConfigDetails,
    "InstanceConfigurationLaunchOptions": InstanceConfigurationLaunchOptions,
    "InstanceConfigurationParavirtualizedAttachVolumeDetails": InstanceConfigurationParavirtualizedAttachVolumeDetails,
    "InstanceConfigurationSummary": InstanceConfigurationSummary,
    "InstanceConfigurationVolumeSourceDetails": InstanceConfigurationVolumeSourceDetails,
    "InstanceConfigurationVolumeSourceFromVolumeBackupDetails": InstanceConfigurationVolumeSourceFromVolumeBackupDetails,
    "InstanceConfigurationVolumeSourceFromVolumeDetails": InstanceConfigurationVolumeSourceFromVolumeDetails,
    "InstanceConsoleConnection": InstanceConsoleConnection,
    "InstanceCredentials": InstanceCredentials,
    "InstancePool": InstancePool,
    "InstancePoolInstanceLoadBalancerBackend": InstancePoolInstanceLoadBalancerBackend,
    "InstancePoolLoadBalancerAttachment": InstancePoolLoadBalancerAttachment,
    "InstancePoolPlacementConfiguration": InstancePoolPlacementConfiguration,
    "InstancePoolPlacementSecondaryVnicSubnet": InstancePoolPlacementSecondaryVnicSubnet,
    "InstancePoolSummary": InstancePoolSummary,
    "InstanceShapeConfig": InstanceShapeConfig,
    "InstanceSourceDetails": InstanceSourceDetails,
    "InstanceSourceViaBootVolumeDetails": InstanceSourceViaBootVolumeDetails,
    "InstanceSourceViaImageDetails": InstanceSourceViaImageDetails,
    "InstanceSummary": InstanceSummary,
    "InternetGateway": InternetGateway,
    "Ipv6": Ipv6,
    "LaunchInstanceAgentConfigDetails": LaunchInstanceAgentConfigDetails,
    "LaunchInstanceAvailabilityConfigDetails": LaunchInstanceAvailabilityConfigDetails,
    "LaunchInstanceDetails": LaunchInstanceDetails,
    "LaunchInstanceShapeConfigDetails": LaunchInstanceShapeConfigDetails,
    "LaunchOptions": LaunchOptions,
    "LetterOfAuthority": LetterOfAuthority,
    "LocalPeeringGateway": LocalPeeringGateway,
    "NatGateway": NatGateway,
    "NetworkSecurityGroup": NetworkSecurityGroup,
    "NetworkSecurityGroupVnic": NetworkSecurityGroupVnic,
    "ParavirtualizedVolumeAttachment": ParavirtualizedVolumeAttachment,
    "PeerRegionForRemotePeering": PeerRegionForRemotePeering,
    "PortRange": PortRange,
    "PrivateIp": PrivateIp,
    "PublicIp": PublicIp,
    "PublicIpPool": PublicIpPool,
    "PublicIpPoolCollection": PublicIpPoolCollection,
    "PublicIpPoolSummary": PublicIpPoolSummary,
    "RemotePeeringConnection": RemotePeeringConnection,
    "RemoveNetworkSecurityGroupSecurityRulesDetails": RemoveNetworkSecurityGroupSecurityRulesDetails,
    "RemovePublicIpPoolCapacityDetails": RemovePublicIpPoolCapacityDetails,
    "RouteRule": RouteRule,
    "RouteTable": RouteTable,
    "SecurityList": SecurityList,
    "SecurityRule": SecurityRule,
    "Service": Service,
    "ServiceGateway": ServiceGateway,
    "ServiceIdRequestDetails": ServiceIdRequestDetails,
    "ServiceIdResponseDetails": ServiceIdResponseDetails,
    "Shape": Shape,
    "ShapeMaxVnicAttachmentOptions": ShapeMaxVnicAttachmentOptions,
    "ShapeMemoryOptions": ShapeMemoryOptions,
    "ShapeNetworkingBandwidthOptions": ShapeNetworkingBandwidthOptions,
    "ShapeOcpuOptions": ShapeOcpuOptions,
    "Subnet": Subnet,
    "TcpOptions": TcpOptions,
    "TunnelConfig": TunnelConfig,
    "TunnelCpeDeviceConfig": TunnelCpeDeviceConfig,
    "TunnelStatus": TunnelStatus,
    "UdpOptions": UdpOptions,
    "UpdateBootVolumeBackupDetails": UpdateBootVolumeBackupDetails,
    "UpdateBootVolumeDetails": UpdateBootVolumeDetails,
    "UpdateBootVolumeKmsKeyDetails": UpdateBootVolumeKmsKeyDetails,
    "UpdateByoipRangeDetails": UpdateByoipRangeDetails,
    "UpdateClusterNetworkDetails": UpdateClusterNetworkDetails,
    "UpdateComputeImageCapabilitySchemaDetails": UpdateComputeImageCapabilitySchemaDetails,
    "UpdateConsoleHistoryDetails": UpdateConsoleHistoryDetails,
    "UpdateCpeDetails": UpdateCpeDetails,
    "UpdateCrossConnectDetails": UpdateCrossConnectDetails,
    "UpdateCrossConnectGroupDetails": UpdateCrossConnectGroupDetails,
    "UpdateDedicatedVmHostDetails": UpdateDedicatedVmHostDetails,
    "UpdateDhcpDetails": UpdateDhcpDetails,
    "UpdateDrgAttachmentDetails": UpdateDrgAttachmentDetails,
    "UpdateDrgDetails": UpdateDrgDetails,
    "UpdateIPSecConnectionDetails": UpdateIPSecConnectionDetails,
    "UpdateIPSecConnectionTunnelDetails": UpdateIPSecConnectionTunnelDetails,
    "UpdateIPSecConnectionTunnelSharedSecretDetails": UpdateIPSecConnectionTunnelSharedSecretDetails,
    "UpdateIPSecTunnelBgpSessionDetails": UpdateIPSecTunnelBgpSessionDetails,
    "UpdateImageDetails": UpdateImageDetails,
    "UpdateInstanceAgentConfigDetails": UpdateInstanceAgentConfigDetails,
    "UpdateInstanceAvailabilityConfigDetails": UpdateInstanceAvailabilityConfigDetails,
    "UpdateInstanceConfigurationDetails": UpdateInstanceConfigurationDetails,
    "UpdateInstanceConsoleConnectionDetails": UpdateInstanceConsoleConnectionDetails,
    "UpdateInstanceDetails": UpdateInstanceDetails,
    "UpdateInstancePoolDetails": UpdateInstancePoolDetails,
    "UpdateInstancePoolPlacementConfigurationDetails": UpdateInstancePoolPlacementConfigurationDetails,
    "UpdateInstanceShapeConfigDetails": UpdateInstanceShapeConfigDetails,
    "UpdateInternetGatewayDetails": UpdateInternetGatewayDetails,
    "UpdateIpv6Details": UpdateIpv6Details,
    "UpdateLaunchOptions": UpdateLaunchOptions,
    "UpdateLocalPeeringGatewayDetails": UpdateLocalPeeringGatewayDetails,
    "UpdateNatGatewayDetails": UpdateNatGatewayDetails,
    "UpdateNetworkSecurityGroupDetails": UpdateNetworkSecurityGroupDetails,
    "UpdateNetworkSecurityGroupSecurityRulesDetails": UpdateNetworkSecurityGroupSecurityRulesDetails,
    "UpdatePrivateIpDetails": UpdatePrivateIpDetails,
    "UpdatePublicIpDetails": UpdatePublicIpDetails,
    "UpdatePublicIpPoolDetails": UpdatePublicIpPoolDetails,
    "UpdateRemotePeeringConnectionDetails": UpdateRemotePeeringConnectionDetails,
    "UpdateRouteTableDetails": UpdateRouteTableDetails,
    "UpdateSecurityListDetails": UpdateSecurityListDetails,
    "UpdateSecurityRuleDetails": UpdateSecurityRuleDetails,
    "UpdateServiceGatewayDetails": UpdateServiceGatewayDetails,
    "UpdateSubnetDetails": UpdateSubnetDetails,
    "UpdateTunnelCpeDeviceConfigDetails": UpdateTunnelCpeDeviceConfigDetails,
    "UpdateVcnDetails": UpdateVcnDetails,
    "UpdateVirtualCircuitDetails": UpdateVirtualCircuitDetails,
    "UpdateVlanDetails": UpdateVlanDetails,
    "UpdateVnicDetails": UpdateVnicDetails,
    "UpdateVolumeBackupDetails": UpdateVolumeBackupDetails,
    "UpdateVolumeBackupPolicyDetails": UpdateVolumeBackupPolicyDetails,
    "UpdateVolumeDetails": UpdateVolumeDetails,
    "UpdateVolumeGroupBackupDetails": UpdateVolumeGroupBackupDetails,
    "UpdateVolumeGroupDetails": UpdateVolumeGroupDetails,
    "UpdateVolumeKmsKeyDetails": UpdateVolumeKmsKeyDetails,
    "UpdatedNetworkSecurityGroupSecurityRules": UpdatedNetworkSecurityGroupSecurityRules,
    "Vcn": Vcn,
    "VirtualCircuit": VirtualCircuit,
    "VirtualCircuitBandwidthShape": VirtualCircuitBandwidthShape,
    "VirtualCircuitPublicPrefix": VirtualCircuitPublicPrefix,
    "Vlan": Vlan,
    "Vnic": Vnic,
    "VnicAttachment": VnicAttachment,
    "Volume": Volume,
    "VolumeAttachment": VolumeAttachment,
    "VolumeBackup": VolumeBackup,
    "VolumeBackupPolicy": VolumeBackupPolicy,
    "VolumeBackupPolicyAssignment": VolumeBackupPolicyAssignment,
    "VolumeBackupSchedule": VolumeBackupSchedule,
    "VolumeGroup": VolumeGroup,
    "VolumeGroupBackup": VolumeGroupBackup,
    "VolumeGroupSourceDetails": VolumeGroupSourceDetails,
    "VolumeGroupSourceFromVolumeGroupBackupDetails": VolumeGroupSourceFromVolumeGroupBackupDetails,
    "VolumeGroupSourceFromVolumeGroupDetails": VolumeGroupSourceFromVolumeGroupDetails,
    "VolumeGroupSourceFromVolumesDetails": VolumeGroupSourceFromVolumesDetails,
    "VolumeKmsKey": VolumeKmsKey,
    "VolumeSourceDetails": VolumeSourceDetails,
    "VolumeSourceFromVolumeBackupDetails": VolumeSourceFromVolumeBackupDetails,
    "VolumeSourceFromVolumeDetails": VolumeSourceFromVolumeDetails
}
